@@ -1,4 +1,7 @@
-from django.conf.urls import patterns, include, url
+try:
+    from django.conf.urls import patterns, include, url
+except ImportError:
+    from django.conf.urls.defaults import *
 
 urlpatterns = patterns('',
     url(r'^complete/$', 'cccontact.views.complete', name='complete'),
